==> zio-aws-iotwireless_2.13-5.17.201.1-sources.jar: zio/aws/iotwireless/model/UpdateNetworkAnalyzerConfigurationRequest.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.{
  Description,
  WirelessGatewayId,
  WirelessDeviceId,
  NetworkAnalyzerConfigurationName
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateNetworkAnalyzerConfigurationRequest(
    configurationName: NetworkAnalyzerConfigurationName,
    traceContent: Optional[zio.aws.iotwireless.model.TraceContent] =
      Optional.Absent,
    wirelessDevicesToAdd: Optional[Iterable[WirelessDeviceId]] =
      Optional.Absent,
    wirelessDevicesToRemove: Optional[Iterable[WirelessDeviceId]] =
      Optional.Absent,
    wirelessGatewaysToAdd: Optional[Iterable[WirelessGatewayId]] =
      Optional.Absent,
    wirelessGatewaysToRemove: Optional[Iterable[WirelessGatewayId]] =
      Optional.Absent,
    description: Optional[Description] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest = {
    import UpdateNetworkAnalyzerConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
      .builder()
      .configurationName(
        NetworkAnalyzerConfigurationName.unwrap(
          configurationName
        ): java.lang.String
      )
      .optionallyWith(traceContent.map(value => value.buildAwsValue()))(
        _.traceContent
      )
      .optionallyWith(
        wirelessDevicesToAdd.map(value =>
          value.map { item =>
            WirelessDeviceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessDevicesToAdd)
      .optionallyWith(
        wirelessDevicesToRemove.map(value =>
          value.map { item =>
            WirelessDeviceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessDevicesToRemove)
      .optionallyWith(
        wirelessGatewaysToAdd.map(value =>
          value.map { item =>
            WirelessGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessGatewaysToAdd)
      .optionallyWith(
        wirelessGatewaysToRemove.map(value =>
          value.map { item =>
            WirelessGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessGatewaysToRemove)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest.ReadOnly =
    zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateNetworkAnalyzerConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest =
      zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest(
        configurationName,
        traceContent.map(value => value.asEditable),
        wirelessDevicesToAdd.map(value => value),
        wirelessDevicesToRemove.map(value => value),
        wirelessGatewaysToAdd.map(value => value),
        wirelessGatewaysToRemove.map(value => value),
        description.map(value => value)
      )
    def configurationName: NetworkAnalyzerConfigurationName
    def traceContent: Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly]
    def wirelessDevicesToAdd: Optional[List[WirelessDeviceId]]
    def wirelessDevicesToRemove: Optional[List[WirelessDeviceId]]
    def wirelessGatewaysToAdd: Optional[List[WirelessGatewayId]]
    def wirelessGatewaysToRemove: Optional[List[WirelessGatewayId]]
    def description: Optional[Description]
    def getConfigurationName
        : ZIO[Any, Nothing, NetworkAnalyzerConfigurationName] =
      ZIO.succeed(configurationName)
    def getTraceContent
        : ZIO[Any, AwsError, zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      AwsError.unwrapOptionField("traceContent", traceContent)
    def getWirelessDevicesToAdd: ZIO[Any, AwsError, List[WirelessDeviceId]] =
      AwsError.unwrapOptionField("wirelessDevicesToAdd", wirelessDevicesToAdd)
    def getWirelessDevicesToRemove: ZIO[Any, AwsError, List[WirelessDeviceId]] =
      AwsError.unwrapOptionField(
        "wirelessDevicesToRemove",
        wirelessDevicesToRemove
      )
    def getWirelessGatewaysToAdd: ZIO[Any, AwsError, List[WirelessGatewayId]] =
      AwsError.unwrapOptionField("wirelessGatewaysToAdd", wirelessGatewaysToAdd)
    def getWirelessGatewaysToRemove
        : ZIO[Any, AwsError, List[WirelessGatewayId]] = AwsError
      .unwrapOptionField("wirelessGatewaysToRemove", wirelessGatewaysToRemove)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
  ) extends zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest.ReadOnly {
    override val configurationName: NetworkAnalyzerConfigurationName =
      zio.aws.iotwireless.model.primitives
        .NetworkAnalyzerConfigurationName(impl.configurationName())
    override val traceContent
        : Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.traceContent())
        .map(value => zio.aws.iotwireless.model.TraceContent.wrap(value))
    override val wirelessDevicesToAdd: Optional[List[WirelessDeviceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessDevicesToAdd())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessDeviceId(item)
          }.toList
        )
    override val wirelessDevicesToRemove: Optional[List[WirelessDeviceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessDevicesToRemove())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessDeviceId(item)
          }.toList
        )
    override val wirelessGatewaysToAdd: Optional[List[WirelessGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessGatewaysToAdd())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessGatewayId(item)
          }.toList
        )
    override val wirelessGatewaysToRemove: Optional[List[WirelessGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessGatewaysToRemove())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessGatewayId(item)
          }.toList
        )
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotwireless.model.primitives.Description(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
  ): zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotwireless_2.13-7.21.15.12-sources.jar: zio/aws/iotwireless/model/UpdateNetworkAnalyzerConfigurationRequest.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.{
  WirelessGatewayId,
  NetworkAnalyzerConfigurationName,
  MulticastGroupId,
  Description,
  WirelessDeviceId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateNetworkAnalyzerConfigurationRequest(
    configurationName: NetworkAnalyzerConfigurationName,
    traceContent: Optional[zio.aws.iotwireless.model.TraceContent] =
      Optional.Absent,
    wirelessDevicesToAdd: Optional[Iterable[WirelessDeviceId]] =
      Optional.Absent,
    wirelessDevicesToRemove: Optional[Iterable[WirelessDeviceId]] =
      Optional.Absent,
    wirelessGatewaysToAdd: Optional[Iterable[WirelessGatewayId]] =
      Optional.Absent,
    wirelessGatewaysToRemove: Optional[Iterable[WirelessGatewayId]] =
      Optional.Absent,
    description: Optional[Description] = Optional.Absent,
    multicastGroupsToAdd: Optional[Iterable[MulticastGroupId]] =
      Optional.Absent,
    multicastGroupsToRemove: Optional[Iterable[MulticastGroupId]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest = {
    import UpdateNetworkAnalyzerConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
      .builder()
      .configurationName(
        NetworkAnalyzerConfigurationName.unwrap(
          configurationName
        ): java.lang.String
      )
      .optionallyWith(traceContent.map(value => value.buildAwsValue()))(
        _.traceContent
      )
      .optionallyWith(
        wirelessDevicesToAdd.map(value =>
          value.map { item =>
            WirelessDeviceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessDevicesToAdd)
      .optionallyWith(
        wirelessDevicesToRemove.map(value =>
          value.map { item =>
            WirelessDeviceId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessDevicesToRemove)
      .optionallyWith(
        wirelessGatewaysToAdd.map(value =>
          value.map { item =>
            WirelessGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessGatewaysToAdd)
      .optionallyWith(
        wirelessGatewaysToRemove.map(value =>
          value.map { item =>
            WirelessGatewayId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.wirelessGatewaysToRemove)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        multicastGroupsToAdd.map(value =>
          value.map { item =>
            MulticastGroupId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.multicastGroupsToAdd)
      .optionallyWith(
        multicastGroupsToRemove.map(value =>
          value.map { item =>
            MulticastGroupId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.multicastGroupsToRemove)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest.ReadOnly =
    zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateNetworkAnalyzerConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest =
      zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest(
        configurationName,
        traceContent.map(value => value.asEditable),
        wirelessDevicesToAdd.map(value => value),
        wirelessDevicesToRemove.map(value => value),
        wirelessGatewaysToAdd.map(value => value),
        wirelessGatewaysToRemove.map(value => value),
        description.map(value => value),
        multicastGroupsToAdd.map(value => value),
        multicastGroupsToRemove.map(value => value)
      )
    def configurationName: NetworkAnalyzerConfigurationName
    def traceContent: Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly]
    def wirelessDevicesToAdd: Optional[List[WirelessDeviceId]]
    def wirelessDevicesToRemove: Optional[List[WirelessDeviceId]]
    def wirelessGatewaysToAdd: Optional[List[WirelessGatewayId]]
    def wirelessGatewaysToRemove: Optional[List[WirelessGatewayId]]
    def description: Optional[Description]
    def multicastGroupsToAdd: Optional[List[MulticastGroupId]]
    def multicastGroupsToRemove: Optional[List[MulticastGroupId]]
    def getConfigurationName
        : ZIO[Any, Nothing, NetworkAnalyzerConfigurationName] =
      ZIO.succeed(configurationName)
    def getTraceContent
        : ZIO[Any, AwsError, zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      AwsError.unwrapOptionField("traceContent", traceContent)
    def getWirelessDevicesToAdd: ZIO[Any, AwsError, List[WirelessDeviceId]] =
      AwsError.unwrapOptionField("wirelessDevicesToAdd", wirelessDevicesToAdd)
    def getWirelessDevicesToRemove: ZIO[Any, AwsError, List[WirelessDeviceId]] =
      AwsError.unwrapOptionField(
        "wirelessDevicesToRemove",
        wirelessDevicesToRemove
      )
    def getWirelessGatewaysToAdd: ZIO[Any, AwsError, List[WirelessGatewayId]] =
      AwsError.unwrapOptionField("wirelessGatewaysToAdd", wirelessGatewaysToAdd)
    def getWirelessGatewaysToRemove
        : ZIO[Any, AwsError, List[WirelessGatewayId]] = AwsError
      .unwrapOptionField("wirelessGatewaysToRemove", wirelessGatewaysToRemove)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getMulticastGroupsToAdd: ZIO[Any, AwsError, List[MulticastGroupId]] =
      AwsError.unwrapOptionField("multicastGroupsToAdd", multicastGroupsToAdd)
    def getMulticastGroupsToRemove: ZIO[Any, AwsError, List[MulticastGroupId]] =
      AwsError.unwrapOptionField(
        "multicastGroupsToRemove",
        multicastGroupsToRemove
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
  ) extends zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest.ReadOnly {
    override val configurationName: NetworkAnalyzerConfigurationName =
      zio.aws.iotwireless.model.primitives
        .NetworkAnalyzerConfigurationName(impl.configurationName())
    override val traceContent
        : Optional[zio.aws.iotwireless.model.TraceContent.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.traceContent())
        .map(value => zio.aws.iotwireless.model.TraceContent.wrap(value))
    override val wirelessDevicesToAdd: Optional[List[WirelessDeviceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessDevicesToAdd())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessDeviceId(item)
          }.toList
        )
    override val wirelessDevicesToRemove: Optional[List[WirelessDeviceId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessDevicesToRemove())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessDeviceId(item)
          }.toList
        )
    override val wirelessGatewaysToAdd: Optional[List[WirelessGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessGatewaysToAdd())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessGatewayId(item)
          }.toList
        )
    override val wirelessGatewaysToRemove: Optional[List[WirelessGatewayId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.wirelessGatewaysToRemove())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.WirelessGatewayId(item)
          }.toList
        )
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.iotwireless.model.primitives.Description(value))
    override val multicastGroupsToAdd: Optional[List[MulticastGroupId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.multicastGroupsToAdd())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.MulticastGroupId(item)
          }.toList
        )
    override val multicastGroupsToRemove: Optional[List[MulticastGroupId]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.multicastGroupsToRemove())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.iotwireless.model.primitives.MulticastGroupId(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest
  ): zio.aws.iotwireless.model.UpdateNetworkAnalyzerConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
